package sun.awt.datatransfer;

import java.util.HashSet;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.io.IOException;
import java.util.HashMap;
import java.io.OutputStream;
import java.util.Set;
import java.util.Map;
import java.io.ObjectOutputStream;

final class ClassLoaderObjectOutputStream extends ObjectOutputStream
{
    private final Map<Set<String>, ClassLoader> map;
    
    ClassLoaderObjectOutputStream(OutputStream out) throws IOException {
        super(out);
        this.map = new HashMap();
    }
    
    @Override
    protected void annotateClass(final Class<?> clazz) throws IOException {
        ClassLoader classLoader = (ClassLoader)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return clazz.getClassLoader();
            }
        });
        HashSet set = new HashSet(1);
        set.add(clazz.getName());
        this.map.put(set, classLoader);
    }
    
    @Override
    protected void annotateProxyClass(final Class<?> clazz) throws IOException {
        ClassLoader classLoader = (ClassLoader)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return clazz.getClassLoader();
            }
        });
        Class[] interfaces = clazz.getInterfaces();
        HashSet set = new HashSet(interfaces.length);
        for (int i = 0; i < interfaces.length; ++i) {
            set.add(interfaces[i].getName());
        }
        this.map.put(set, classLoader);
    }
    
    Map<Set<String>, ClassLoader> getClassLoaderMap() {
        return new HashMap(this.map);
    }
}
